R/prod.R
make_function.product.Rd
Build a function that is the product of two other functions
# S3 method for class 'product' make_function(F_obj)
a function object
a function that is the product of two other functions