Skip to contents

Build a function to model a forced seasonal signal. The shape parameters determine the timing, frequency, and relative intensity over the season. The function is normalized to have an annual value set by norm

Usage

# S3 method for class 'sigmoid'
make_function(F_obj)

Arguments

F_obj

a function object, F_obj

Value

a function