R/sum.R
make_function.sum.Rd
Build a function that is the sum of two other functions.
# S3 method for class 'sum' make_function(F_obj)
a function object
a function that is the sum of two other functions