A spline function \(F_T(t)\) for trends is specified by a set of \(n\) interpolating points:
time values $$t_1, t_2, \ldots, t_n,$$
and corresponding \(y\) values $$y_1, y_2, \ldots, y_n.$$
For splineX, the return value is $$e^{F_T(t)}$$
A spline function \(F_T(t)\) for trends is specified by a set of \(n\) interpolating points:
time values $$t_1, t_2, \ldots, t_n,$$
and corresponding \(y\) values $$y_1, y_2, \ldots, y_n.$$
For splineX, the return value is $$e^{F_T(t)}$$