Skip to contents

Build a function that is the product of two other functions

Usage

# S3 method for class 'product'
make_function(F_obj)

Arguments

F_obj

a function object, F_obj

Value

a function that is the product of two other functions